/* Copyright (c) 1990 by Carrick Sean Casey. */
/* For copying and distribution information, see the file COPYING. */

#include "fn.h"
#include "externs.h"
#include "../version.h"
#include <sys/wait.h>
#include <sys/dir.h>

main (argc, argv)
int argc;
char **argv;
{
	int c;
	extern char *optarg;
	char *getenv(), *getpass(), *getloginid();
	int restrictflg = 0;
	int telnetflg = 0;
	int clearargsflg = 0;

	while ((c = getopt(argc, argv, "g:n:cwrt")) != EOF) {

		static char nick[MAX_NICKLEN];
		static char group[MAX_GROUPLEN];

		switch (c) {

		case 'c':
			clearargsflg++;
			break;

		case 'g':
			strcpy(group, optarg);
			mygroup = group;
			break;

		case 'n':
			strcpy(nick, optarg);
			mynick = nick;
			break;

		case 'w':
			whoflg++;
			gv.interactive = 0;
			break;

		case 'r':
			restrictflg = 1;
			break;

		case 't':
			restrictflg = 1;
			telnetflg = 1;
			break;

		case '?':
		default:
			puts("usage: fn [-crw] [-n nick] [-g group]\r");
			puts("-c	 wipe args from command line\r");
			puts("-r         restricted mode\r");
			puts("-w         do a who without signing on\r");
			puts("-n nick    enter with nickname set to nick\r");
			puts("-g group   enter into specified group\r");
			exit(-1);
			break;
		}
	}

	if (clearargsflg)
		clearargs(argc, argv);

	/* PLEASE DO NOT FAKE LOGIN IDS - IT IS AGAINST FORUMNET RULES */

	if (telnetflg)
		myloginid = "ukpr";
	else
		if ((myloginid = getloginid()) == NULL) {
			puts("Error - can't determine your login ID.");
			exit(-1);
		}
	
	/* get our nickname */
	if (mynick == 0)
		if ((mynick = getenv("FORUMNAME")) == NULL)
			mynick = myloginid;
	
	/* start up the server if we can and if we must */
	gethostname(thishost, 127);

	/* can you believe this program uses random numbers? */
	srandom((unsigned)time(0));


	/* read .rc file and say hello */
	if (gv.interactive) {
		tclinit();
		tclreadfnrc();
		if (restrictflg && !gv.restricted)
			restrict();
		sprintf(mbuf, "Fn revision %s. Type \"%chelp\" for help.\r\n",
		  VERSION, gv.cmdchar);
		write(1, mbuf, strlen(mbuf));
	}

	/* try to connect to port - if it fails, start server if we are on */
	/* same machne then try again */

	if ((connecttoport(DEFAULTHOST, DEFAULTPORT)) < 0) {
		perror("forum: remote server not running");
		exit(-1);
	}

	if (gv.interactive) {
		/* stash old term settings */
		getterm();

		/* set up terminal mode */
		fnterm();

		/* trap signals */
		trapsignals();
	}


	/* start the serve loop */
	if (clientserve() < 0) {
		perror("clientserve failed");
		exit(-1);
	}

	/* all's well that ends */
	exit(0);
}

fnexit()
{
	/* retore term modes */
	if (gv.interactive)
		restoreterm();
	
	/* close the session log */
	if (logging())
		closesessionlog();

	exit(0);
}
